openapi

package
v0.0.0-...-b934907 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 17, 2024 License: MIT Imports: 20 Imported by: 0

README

Go API client for openapi

Actual example use cases for a curated list of golang api generator libraries

Overview

This API client was generated by the OpenAPI Generator project. By using the OpenAPI-spec from a remote server, you can easily generate an API client.

  • API version: 1.0.0
  • Package version: 1.0.0
  • Generator version: 7.8.0
  • Build package: org.openapitools.codegen.languages.GoClientCodegen

Installation

Install the following dependencies:

go get github.com/stretchr/testify/assert
go get golang.org/x/net/context

Put the package under your project folder and add the following in import:

import openapi "github.com/veqryn/awesome-go-api/protobufv3/openapiv3/openapi_generator/go/gen"

To use a proxy, set the environment variable HTTP_PROXY:

os.Setenv("HTTP_PROXY", "http://proxy_name:proxy_port")

Configuration of Server URL

Default configuration comes with Servers field that contains server objects as defined in the OpenAPI specification.

Select Server Configuration

For using other server than the one defined on index 0 set context value openapi.ContextServerIndex of type int.

ctx := context.WithValue(context.Background(), openapi.ContextServerIndex, 1)
Templated Server URL

Templated server URL is formatted using default variables from configuration or from context value openapi.ContextServerVariables of type map[string]string.

ctx := context.WithValue(context.Background(), openapi.ContextServerVariables, map[string]string{
	"basePath": "v2",
})

Note, enum values are always validated and all unused variables are silently ignored.

URLs Configuration per Operation

Each operation can use different server URL defined using OperationServers map in the Configuration. An operation is uniquely identified by "{classname}Service.{nickname}" string. Similar rules for overriding default operation server index and variables applies by using openapi.ContextOperationServerIndices and openapi.ContextOperationServerVariables context maps.

ctx := context.WithValue(context.Background(), openapi.ContextOperationServerIndices, map[string]int{
	"{classname}Service.{nickname}": 2,
})
ctx = context.WithValue(context.Background(), openapi.ContextOperationServerVariables, map[string]map[string]string{
	"{classname}Service.{nickname}": {
		"port": "8443",
	},
})

Documentation for API Endpoints

All URIs are relative to http://localhost:8080

Class Method HTTP request Description
DefaultAPI DefaultError Get /error Get an error
DefaultAPI DefaultGreeting Get /greeting/{name} Say hello to someone
DefaultAPI DefaultReview Post /reviews Send a review

Documentation For Models

Documentation For Authorization

Endpoints do not require authorization.

Documentation for Utility Methods

Due to the fact that model structure members are all pointers, this package contains a number of utility functions to easily obtain pointers to values of basic types. Each of these functions takes a value of the given basic type and returns a pointer to it:

  • PtrBool
  • PtrInt
  • PtrInt32
  • PtrInt64
  • PtrFloat
  • PtrFloat32
  • PtrFloat64
  • PtrString
  • PtrTime

Author

Documentation

Index

Constants

This section is empty.

Variables

var (
	JsonCheck = regexp.MustCompile(`(?i:(?:application|text)/(?:[^;]+\+)?json)`)
	XmlCheck  = regexp.MustCompile(`(?i:(?:application|text)/(?:[^;]+\+)?xml)`)
)
var (
	// ContextServerIndex uses a server configuration from the index.
	ContextServerIndex = contextKey("serverIndex")

	// ContextOperationServerIndices uses a server configuration from the index mapping.
	ContextOperationServerIndices = contextKey("serverOperationIndices")

	// ContextServerVariables overrides a server configuration variables.
	ContextServerVariables = contextKey("serverVariables")

	// ContextOperationServerVariables overrides a server configuration variables using operation specific values.
	ContextOperationServerVariables = contextKey("serverOperationVariables")
)

Functions

func CacheExpires

func CacheExpires(r *http.Response) time.Time

CacheExpires helper function to determine remaining time before repeating a request.

func IsNil

func IsNil(i interface{}) bool

IsNil checks if an input is nil

func PtrBool

func PtrBool(v bool) *bool

PtrBool is a helper routine that returns a pointer to given boolean value.

func PtrFloat32

func PtrFloat32(v float32) *float32

PtrFloat32 is a helper routine that returns a pointer to given float value.

func PtrFloat64

func PtrFloat64(v float64) *float64

PtrFloat64 is a helper routine that returns a pointer to given float value.

func PtrInt

func PtrInt(v int) *int

PtrInt is a helper routine that returns a pointer to given integer value.

func PtrInt32

func PtrInt32(v int32) *int32

PtrInt32 is a helper routine that returns a pointer to given integer value.

func PtrInt64

func PtrInt64(v int64) *int64

PtrInt64 is a helper routine that returns a pointer to given integer value.

func PtrString

func PtrString(v string) *string

PtrString is a helper routine that returns a pointer to given string value.

func PtrTime

func PtrTime(v time.Time) *time.Time

PtrTime is helper routine that returns a pointer to given Time value.

Types

type APIClient

type APIClient struct {
	DefaultAPI DefaultAPI
	// contains filtered or unexported fields
}

APIClient manages communication with the Awesome GO API API v1.0.0 In most cases there should be only one, shared, APIClient.

func NewAPIClient

func NewAPIClient(cfg *Configuration) *APIClient

NewAPIClient creates a new API client. Requires a userAgent string describing your application. optionally a custom http.Client to allow for advanced features such as caching.

func (*APIClient) GetConfig

func (c *APIClient) GetConfig() *Configuration

Allow modification of underlying config for alternate implementations and testing Caution: modifying the configuration while live can cause data races and potentially unwanted behavior

type APIKey

type APIKey struct {
	Key    string
	Prefix string
}

APIKey provides API key based authentication to a request passed via context using ContextAPIKey

type APIResponse

type APIResponse struct {
	*http.Response `json:"-"`
	Message        string `json:"message,omitempty"`
	// Operation is the name of the OpenAPI operation.
	Operation string `json:"operation,omitempty"`
	// RequestURL is the request URL. This value is always available, even if the
	// embedded *http.Response is nil.
	RequestURL string `json:"url,omitempty"`
	// Method is the HTTP method used for the request.  This value is always
	// available, even if the embedded *http.Response is nil.
	Method string `json:"method,omitempty"`
	// Payload holds the contents of the response body (which may be nil or empty).
	// This is provided here as the raw response.Body() reader will have already
	// been drained.
	Payload []byte `json:"-"`
}

APIResponse stores the API response returned by the server.

func NewAPIResponse

func NewAPIResponse(r *http.Response) *APIResponse

NewAPIResponse returns a new APIResponse object.

func NewAPIResponseWithError

func NewAPIResponseWithError(errorMessage string) *APIResponse

NewAPIResponseWithError returns a new APIResponse object with the provided error message.

type ApiDefaultErrorRequest

type ApiDefaultErrorRequest struct {
	ApiService DefaultAPI
	// contains filtered or unexported fields
}

func (ApiDefaultErrorRequest) Execute

func (r ApiDefaultErrorRequest) Execute() (map[string]interface{}, *http.Response, error)

type ApiDefaultGreetingRequest

type ApiDefaultGreetingRequest struct {
	ApiService DefaultAPI
	// contains filtered or unexported fields
}

func (ApiDefaultGreetingRequest) Execute

type ApiDefaultReviewRequest

type ApiDefaultReviewRequest struct {
	ApiService DefaultAPI
	// contains filtered or unexported fields
}

func (ApiDefaultReviewRequest) Body

func (ApiDefaultReviewRequest) Execute

func (r ApiDefaultReviewRequest) Execute() (map[string]interface{}, *http.Response, error)

type AwesomeGreetingResp

type AwesomeGreetingResp struct {
	// Greeting message
	Message string `json:"message"`
}

AwesomeGreetingResp struct for AwesomeGreetingResp

func NewAwesomeGreetingResp

func NewAwesomeGreetingResp(message string) *AwesomeGreetingResp

NewAwesomeGreetingResp instantiates a new AwesomeGreetingResp object This constructor will assign default values to properties that have it defined, and makes sure properties required by API are set, but the set of arguments will change when the set of required properties is changed

func NewAwesomeGreetingRespWithDefaults

func NewAwesomeGreetingRespWithDefaults() *AwesomeGreetingResp

NewAwesomeGreetingRespWithDefaults instantiates a new AwesomeGreetingResp object This constructor will only assign default values to properties that have it defined, but it doesn't guarantee that properties required by API are set

func (*AwesomeGreetingResp) GetMessage

func (o *AwesomeGreetingResp) GetMessage() string

GetMessage returns the Message field value

func (*AwesomeGreetingResp) GetMessageOk

func (o *AwesomeGreetingResp) GetMessageOk() (*string, bool)

GetMessageOk returns a tuple with the Message field value and a boolean to check if the value has been set.

func (AwesomeGreetingResp) MarshalJSON

func (o AwesomeGreetingResp) MarshalJSON() ([]byte, error)

func (*AwesomeGreetingResp) SetMessage

func (o *AwesomeGreetingResp) SetMessage(v string)

SetMessage sets field value

func (AwesomeGreetingResp) ToMap

func (o AwesomeGreetingResp) ToMap() (map[string]interface{}, error)

func (*AwesomeGreetingResp) UnmarshalJSON

func (o *AwesomeGreetingResp) UnmarshalJSON(data []byte) (err error)

type AwesomeReviewReq

type AwesomeReviewReq struct {
	// Author of the review
	Author string `json:"author"`
	// Review message
	Message *string `json:"message,omitempty"`
	// Rating from 1 to 5
	Rating int64 `json:"rating"`
}

AwesomeReviewReq struct for AwesomeReviewReq

func NewAwesomeReviewReq

func NewAwesomeReviewReq(author string, rating int64) *AwesomeReviewReq

NewAwesomeReviewReq instantiates a new AwesomeReviewReq object This constructor will assign default values to properties that have it defined, and makes sure properties required by API are set, but the set of arguments will change when the set of required properties is changed

func NewAwesomeReviewReqWithDefaults

func NewAwesomeReviewReqWithDefaults() *AwesomeReviewReq

NewAwesomeReviewReqWithDefaults instantiates a new AwesomeReviewReq object This constructor will only assign default values to properties that have it defined, but it doesn't guarantee that properties required by API are set

func (*AwesomeReviewReq) GetAuthor

func (o *AwesomeReviewReq) GetAuthor() string

GetAuthor returns the Author field value

func (*AwesomeReviewReq) GetAuthorOk

func (o *AwesomeReviewReq) GetAuthorOk() (*string, bool)

GetAuthorOk returns a tuple with the Author field value and a boolean to check if the value has been set.

func (*AwesomeReviewReq) GetMessage

func (o *AwesomeReviewReq) GetMessage() string

GetMessage returns the Message field value if set, zero value otherwise.

func (*AwesomeReviewReq) GetMessageOk

func (o *AwesomeReviewReq) GetMessageOk() (*string, bool)

GetMessageOk returns a tuple with the Message field value if set, nil otherwise and a boolean to check if the value has been set.

func (*AwesomeReviewReq) GetRating

func (o *AwesomeReviewReq) GetRating() int64

GetRating returns the Rating field value

func (*AwesomeReviewReq) GetRatingOk

func (o *AwesomeReviewReq) GetRatingOk() (*int64, bool)

GetRatingOk returns a tuple with the Rating field value and a boolean to check if the value has been set.

func (*AwesomeReviewReq) HasMessage

func (o *AwesomeReviewReq) HasMessage() bool

HasMessage returns a boolean if a field has been set.

func (AwesomeReviewReq) MarshalJSON

func (o AwesomeReviewReq) MarshalJSON() ([]byte, error)

func (*AwesomeReviewReq) SetAuthor

func (o *AwesomeReviewReq) SetAuthor(v string)

SetAuthor sets field value

func (*AwesomeReviewReq) SetMessage

func (o *AwesomeReviewReq) SetMessage(v string)

SetMessage gets a reference to the given string and assigns it to the Message field.

func (*AwesomeReviewReq) SetRating

func (o *AwesomeReviewReq) SetRating(v int64)

SetRating sets field value

func (AwesomeReviewReq) ToMap

func (o AwesomeReviewReq) ToMap() (map[string]interface{}, error)

func (*AwesomeReviewReq) UnmarshalJSON

func (o *AwesomeReviewReq) UnmarshalJSON(data []byte) (err error)

type BasicAuth

type BasicAuth struct {
	UserName string `json:"userName,omitempty"`
	Password string `json:"password,omitempty"`
}

BasicAuth provides basic http authentication to a request passed via context using ContextBasicAuth

type Configuration

type Configuration struct {
	Host             string            `json:"host,omitempty"`
	Scheme           string            `json:"scheme,omitempty"`
	DefaultHeader    map[string]string `json:"defaultHeader,omitempty"`
	UserAgent        string            `json:"userAgent,omitempty"`
	Debug            bool              `json:"debug,omitempty"`
	Servers          ServerConfigurations
	OperationServers map[string]ServerConfigurations
	HTTPClient       *http.Client
}

Configuration stores the configuration of the API client

func NewConfiguration

func NewConfiguration() *Configuration

NewConfiguration returns a new Configuration object

func (*Configuration) AddDefaultHeader

func (c *Configuration) AddDefaultHeader(key string, value string)

AddDefaultHeader adds a new HTTP header to the default header in the request

func (*Configuration) ServerURL

func (c *Configuration) ServerURL(index int, variables map[string]string) (string, error)

ServerURL returns URL based on server settings

func (*Configuration) ServerURLWithContext

func (c *Configuration) ServerURLWithContext(ctx context.Context, endpoint string) (string, error)

ServerURLWithContext returns a new server URL given an endpoint

type DefaultAPI

type DefaultAPI interface {

	/*
		DefaultError Get an error

		Responds with an error

		@param ctx context.Context - for authentication, logging, cancellation, deadlines, tracing, etc. Passed from http.Request or context.Background().
		@return ApiDefaultErrorRequest
	*/
	DefaultError(ctx context.Context) ApiDefaultErrorRequest

	// DefaultErrorExecute executes the request
	//  @return map[string]interface{}
	DefaultErrorExecute(r ApiDefaultErrorRequest) (map[string]interface{}, *http.Response, error)

	/*
		DefaultGreeting Say hello to someone

		Responds with a greeting

		@param ctx context.Context - for authentication, logging, cancellation, deadlines, tracing, etc. Passed from http.Request or context.Background().
		@param name Name to greet
		@return ApiDefaultGreetingRequest
	*/
	DefaultGreeting(ctx context.Context, name string) ApiDefaultGreetingRequest

	// DefaultGreetingExecute executes the request
	//  @return AwesomeGreetingResp
	DefaultGreetingExecute(r ApiDefaultGreetingRequest) (*AwesomeGreetingResp, *http.Response, error)

	/*
		DefaultReview Send a review

		Post a review to be saved

		@param ctx context.Context - for authentication, logging, cancellation, deadlines, tracing, etc. Passed from http.Request or context.Background().
		@return ApiDefaultReviewRequest
	*/
	DefaultReview(ctx context.Context) ApiDefaultReviewRequest

	// DefaultReviewExecute executes the request
	//  @return map[string]interface{}
	DefaultReviewExecute(r ApiDefaultReviewRequest) (map[string]interface{}, *http.Response, error)
}

type DefaultAPIService

type DefaultAPIService service

DefaultAPIService DefaultAPI service

func (*DefaultAPIService) DefaultError

DefaultError Get an error

Responds with an error

@param ctx context.Context - for authentication, logging, cancellation, deadlines, tracing, etc. Passed from http.Request or context.Background().
@return ApiDefaultErrorRequest

func (*DefaultAPIService) DefaultErrorExecute

func (a *DefaultAPIService) DefaultErrorExecute(r ApiDefaultErrorRequest) (map[string]interface{}, *http.Response, error)

Execute executes the request

@return map[string]interface{}

func (*DefaultAPIService) DefaultGreeting

func (a *DefaultAPIService) DefaultGreeting(ctx context.Context, name string) ApiDefaultGreetingRequest

DefaultGreeting Say hello to someone

Responds with a greeting

@param ctx context.Context - for authentication, logging, cancellation, deadlines, tracing, etc. Passed from http.Request or context.Background().
@param name Name to greet
@return ApiDefaultGreetingRequest

func (*DefaultAPIService) DefaultGreetingExecute

Execute executes the request

@return AwesomeGreetingResp

func (*DefaultAPIService) DefaultReview

DefaultReview Send a review

Post a review to be saved

@param ctx context.Context - for authentication, logging, cancellation, deadlines, tracing, etc. Passed from http.Request or context.Background().
@return ApiDefaultReviewRequest

func (*DefaultAPIService) DefaultReviewExecute

func (a *DefaultAPIService) DefaultReviewExecute(r ApiDefaultReviewRequest) (map[string]interface{}, *http.Response, error)

Execute executes the request

@return map[string]interface{}

type GenericOpenAPIError

type GenericOpenAPIError struct {
	// contains filtered or unexported fields
}

GenericOpenAPIError Provides access to the body, error and model on returned errors.

func (GenericOpenAPIError) Body

func (e GenericOpenAPIError) Body() []byte

Body returns the raw bytes of the response

func (GenericOpenAPIError) Error

func (e GenericOpenAPIError) Error() string

Error returns non-empty string if there was an error.

func (GenericOpenAPIError) Model

func (e GenericOpenAPIError) Model() interface{}

Model returns the unpacked model of the error

type MappedNullable

type MappedNullable interface {
	ToMap() (map[string]interface{}, error)
}

type NullableAwesomeGreetingResp

type NullableAwesomeGreetingResp struct {
	// contains filtered or unexported fields
}

func NewNullableAwesomeGreetingResp

func NewNullableAwesomeGreetingResp(val *AwesomeGreetingResp) *NullableAwesomeGreetingResp

func (NullableAwesomeGreetingResp) Get

func (NullableAwesomeGreetingResp) IsSet

func (NullableAwesomeGreetingResp) MarshalJSON

func (v NullableAwesomeGreetingResp) MarshalJSON() ([]byte, error)

func (*NullableAwesomeGreetingResp) Set

func (*NullableAwesomeGreetingResp) UnmarshalJSON

func (v *NullableAwesomeGreetingResp) UnmarshalJSON(src []byte) error

func (*NullableAwesomeGreetingResp) Unset

func (v *NullableAwesomeGreetingResp) Unset()

type NullableAwesomeReviewReq

type NullableAwesomeReviewReq struct {
	// contains filtered or unexported fields
}

func NewNullableAwesomeReviewReq

func NewNullableAwesomeReviewReq(val *AwesomeReviewReq) *NullableAwesomeReviewReq

func (NullableAwesomeReviewReq) Get

func (NullableAwesomeReviewReq) IsSet

func (v NullableAwesomeReviewReq) IsSet() bool

func (NullableAwesomeReviewReq) MarshalJSON

func (v NullableAwesomeReviewReq) MarshalJSON() ([]byte, error)

func (*NullableAwesomeReviewReq) Set

func (*NullableAwesomeReviewReq) UnmarshalJSON

func (v *NullableAwesomeReviewReq) UnmarshalJSON(src []byte) error

func (*NullableAwesomeReviewReq) Unset

func (v *NullableAwesomeReviewReq) Unset()

type NullableBool

type NullableBool struct {
	// contains filtered or unexported fields
}

func NewNullableBool

func NewNullableBool(val *bool) *NullableBool

func (NullableBool) Get

func (v NullableBool) Get() *bool

func (NullableBool) IsSet

func (v NullableBool) IsSet() bool

func (NullableBool) MarshalJSON

func (v NullableBool) MarshalJSON() ([]byte, error)

func (*NullableBool) Set

func (v *NullableBool) Set(val *bool)

func (*NullableBool) UnmarshalJSON

func (v *NullableBool) UnmarshalJSON(src []byte) error

func (*NullableBool) Unset

func (v *NullableBool) Unset()

type NullableFloat32

type NullableFloat32 struct {
	// contains filtered or unexported fields
}

func NewNullableFloat32

func NewNullableFloat32(val *float32) *NullableFloat32

func (NullableFloat32) Get

func (v NullableFloat32) Get() *float32

func (NullableFloat32) IsSet

func (v NullableFloat32) IsSet() bool

func (NullableFloat32) MarshalJSON

func (v NullableFloat32) MarshalJSON() ([]byte, error)

func (*NullableFloat32) Set

func (v *NullableFloat32) Set(val *float32)

func (*NullableFloat32) UnmarshalJSON

func (v *NullableFloat32) UnmarshalJSON(src []byte) error

func (*NullableFloat32) Unset

func (v *NullableFloat32) Unset()

type NullableFloat64

type NullableFloat64 struct {
	// contains filtered or unexported fields
}

func NewNullableFloat64

func NewNullableFloat64(val *float64) *NullableFloat64

func (NullableFloat64) Get

func (v NullableFloat64) Get() *float64

func (NullableFloat64) IsSet

func (v NullableFloat64) IsSet() bool

func (NullableFloat64) MarshalJSON

func (v NullableFloat64) MarshalJSON() ([]byte, error)

func (*NullableFloat64) Set

func (v *NullableFloat64) Set(val *float64)

func (*NullableFloat64) UnmarshalJSON

func (v *NullableFloat64) UnmarshalJSON(src []byte) error

func (*NullableFloat64) Unset

func (v *NullableFloat64) Unset()

type NullableInt

type NullableInt struct {
	// contains filtered or unexported fields
}

func NewNullableInt

func NewNullableInt(val *int) *NullableInt

func (NullableInt) Get

func (v NullableInt) Get() *int

func (NullableInt) IsSet

func (v NullableInt) IsSet() bool

func (NullableInt) MarshalJSON

func (v NullableInt) MarshalJSON() ([]byte, error)

func (*NullableInt) Set

func (v *NullableInt) Set(val *int)

func (*NullableInt) UnmarshalJSON

func (v *NullableInt) UnmarshalJSON(src []byte) error

func (*NullableInt) Unset

func (v *NullableInt) Unset()

type NullableInt32

type NullableInt32 struct {
	// contains filtered or unexported fields
}

func NewNullableInt32

func NewNullableInt32(val *int32) *NullableInt32

func (NullableInt32) Get

func (v NullableInt32) Get() *int32

func (NullableInt32) IsSet

func (v NullableInt32) IsSet() bool

func (NullableInt32) MarshalJSON

func (v NullableInt32) MarshalJSON() ([]byte, error)

func (*NullableInt32) Set

func (v *NullableInt32) Set(val *int32)

func (*NullableInt32) UnmarshalJSON

func (v *NullableInt32) UnmarshalJSON(src []byte) error

func (*NullableInt32) Unset

func (v *NullableInt32) Unset()

type NullableInt64

type NullableInt64 struct {
	// contains filtered or unexported fields
}

func NewNullableInt64

func NewNullableInt64(val *int64) *NullableInt64

func (NullableInt64) Get

func (v NullableInt64) Get() *int64

func (NullableInt64) IsSet

func (v NullableInt64) IsSet() bool

func (NullableInt64) MarshalJSON

func (v NullableInt64) MarshalJSON() ([]byte, error)

func (*NullableInt64) Set

func (v *NullableInt64) Set(val *int64)

func (*NullableInt64) UnmarshalJSON

func (v *NullableInt64) UnmarshalJSON(src []byte) error

func (*NullableInt64) Unset

func (v *NullableInt64) Unset()

type NullableProtobufAny

type NullableProtobufAny struct {
	// contains filtered or unexported fields
}

func NewNullableProtobufAny

func NewNullableProtobufAny(val *ProtobufAny) *NullableProtobufAny

func (NullableProtobufAny) Get

func (NullableProtobufAny) IsSet

func (v NullableProtobufAny) IsSet() bool

func (NullableProtobufAny) MarshalJSON

func (v NullableProtobufAny) MarshalJSON() ([]byte, error)

func (*NullableProtobufAny) Set

func (v *NullableProtobufAny) Set(val *ProtobufAny)

func (*NullableProtobufAny) UnmarshalJSON

func (v *NullableProtobufAny) UnmarshalJSON(src []byte) error

func (*NullableProtobufAny) Unset

func (v *NullableProtobufAny) Unset()

type NullableRpcStatus

type NullableRpcStatus struct {
	// contains filtered or unexported fields
}

func NewNullableRpcStatus

func NewNullableRpcStatus(val *RpcStatus) *NullableRpcStatus

func (NullableRpcStatus) Get

func (v NullableRpcStatus) Get() *RpcStatus

func (NullableRpcStatus) IsSet

func (v NullableRpcStatus) IsSet() bool

func (NullableRpcStatus) MarshalJSON

func (v NullableRpcStatus) MarshalJSON() ([]byte, error)

func (*NullableRpcStatus) Set

func (v *NullableRpcStatus) Set(val *RpcStatus)

func (*NullableRpcStatus) UnmarshalJSON

func (v *NullableRpcStatus) UnmarshalJSON(src []byte) error

func (*NullableRpcStatus) Unset

func (v *NullableRpcStatus) Unset()

type NullableString

type NullableString struct {
	// contains filtered or unexported fields
}

func NewNullableString

func NewNullableString(val *string) *NullableString

func (NullableString) Get

func (v NullableString) Get() *string

func (NullableString) IsSet

func (v NullableString) IsSet() bool

func (NullableString) MarshalJSON

func (v NullableString) MarshalJSON() ([]byte, error)

func (*NullableString) Set

func (v *NullableString) Set(val *string)

func (*NullableString) UnmarshalJSON

func (v *NullableString) UnmarshalJSON(src []byte) error

func (*NullableString) Unset

func (v *NullableString) Unset()

type NullableTime

type NullableTime struct {
	// contains filtered or unexported fields
}

func NewNullableTime

func NewNullableTime(val *time.Time) *NullableTime

func (NullableTime) Get

func (v NullableTime) Get() *time.Time

func (NullableTime) IsSet

func (v NullableTime) IsSet() bool

func (NullableTime) MarshalJSON

func (v NullableTime) MarshalJSON() ([]byte, error)

func (*NullableTime) Set

func (v *NullableTime) Set(val *time.Time)

func (*NullableTime) UnmarshalJSON

func (v *NullableTime) UnmarshalJSON(src []byte) error

func (*NullableTime) Unset

func (v *NullableTime) Unset()

type ProtobufAny

type ProtobufAny struct {
	// A URL/resource name that uniquely identifies the type of the serialized protocol buffer message. This string must contain at least one \"/\" character. The last segment of the URL's path must represent the fully qualified name of the type (as in `path/google.protobuf.Duration`). The name should be in a canonical form (e.g., leading \".\" is not accepted).  In practice, teams usually precompile into the binary all types that they expect it to use in the context of Any. However, for URLs which use the scheme `http`, `https`, or no scheme, one can optionally set up a type server that maps type URLs to message definitions as follows:  * If no scheme is provided, `https` is assumed. * An HTTP GET on the URL must yield a [google.protobuf.Type][]   value in binary format, or produce an error. * Applications are allowed to cache lookup results based on the   URL, or have them precompiled into a binary to avoid any   lookup. Therefore, binary compatibility needs to be preserved   on changes to types. (Use versioned type names to manage   breaking changes.)  Note: this functionality is not currently available in the official protobuf release, and it is not used for type URLs beginning with type.googleapis.com. As of May 2023, there are no widely used type server implementations and no plans to implement one.  Schemes other than `http`, `https` (or the empty scheme) might be used with implementation specific semantics.
	Type                 *string `json:"@type,omitempty"`
	AdditionalProperties map[string]interface{}
}

ProtobufAny `Any` contains an arbitrary serialized protocol buffer message along with a URL that describes the type of the serialized message. Protobuf library provides support to pack/unpack Any values in the form of utility functions or additional generated methods of the Any type. Example 1: Pack and unpack a message in C++. Foo foo = ...; Any any; any.PackFrom(foo); ... if (any.UnpackTo(&foo)) { ... } Example 2: Pack and unpack a message in Java. Foo foo = ...; Any any = Any.pack(foo); ... if (any.is(Foo.class)) { foo = any.unpack(Foo.class); } // or ... if (any.isSameTypeAs(Foo.getDefaultInstance())) { foo = any.unpack(Foo.getDefaultInstance()); } Example 3: Pack and unpack a message in Python. foo = Foo(...) any = Any() any.Pack(foo) ... if any.Is(Foo.DESCRIPTOR): any.Unpack(foo) ... Example 4: Pack and unpack a message in Go foo := &pb.Foo{...} any, err := anypb.New(foo) if err != nil { ... } ... foo := &pb.Foo{} if err := any.UnmarshalTo(foo); err != nil { ... } The pack methods provided by protobuf library will by default use 'type.googleapis.com/full.type.name' as the type URL and the unpack methods only use the fully qualified type name after the last '/' in the type URL, for example \"foo.bar.com/x/y.z\" will yield type name \"y.z\". JSON ==== The JSON representation of an `Any` value uses the regular representation of the deserialized, embedded message, with an additional field `@type` which contains the type URL. Example: package google.profile; message Person { string first_name = 1; string last_name = 2; } { \"@type\": \"type.googleapis.com/google.profile.Person\", \"firstName\": <string>, \"lastName\": <string> } If the embedded message type is well-known and has a custom JSON representation, that representation will be embedded adding a field `value` which holds the custom JSON in addition to the `@type` field. Example (for message [google.protobuf.Duration][]): { \"@type\": \"type.googleapis.com/google.protobuf.Duration\", \"value\": \"1.212s\" }

func NewProtobufAny

func NewProtobufAny() *ProtobufAny

NewProtobufAny instantiates a new ProtobufAny object This constructor will assign default values to properties that have it defined, and makes sure properties required by API are set, but the set of arguments will change when the set of required properties is changed

func NewProtobufAnyWithDefaults

func NewProtobufAnyWithDefaults() *ProtobufAny

NewProtobufAnyWithDefaults instantiates a new ProtobufAny object This constructor will only assign default values to properties that have it defined, but it doesn't guarantee that properties required by API are set

func (*ProtobufAny) GetType

func (o *ProtobufAny) GetType() string

GetType returns the Type field value if set, zero value otherwise.

func (*ProtobufAny) GetTypeOk

func (o *ProtobufAny) GetTypeOk() (*string, bool)

GetTypeOk returns a tuple with the Type field value if set, nil otherwise and a boolean to check if the value has been set.

func (*ProtobufAny) HasType

func (o *ProtobufAny) HasType() bool

HasType returns a boolean if a field has been set.

func (ProtobufAny) MarshalJSON

func (o ProtobufAny) MarshalJSON() ([]byte, error)

func (*ProtobufAny) SetType

func (o *ProtobufAny) SetType(v string)

SetType gets a reference to the given string and assigns it to the Type field.

func (ProtobufAny) ToMap

func (o ProtobufAny) ToMap() (map[string]interface{}, error)

func (*ProtobufAny) UnmarshalJSON

func (o *ProtobufAny) UnmarshalJSON(data []byte) (err error)

type RpcStatus

type RpcStatus struct {
	Code    *int32        `json:"code,omitempty"`
	Message *string       `json:"message,omitempty"`
	Details []ProtobufAny `json:"details,omitempty"`
}

RpcStatus struct for RpcStatus

func NewRpcStatus

func NewRpcStatus() *RpcStatus

NewRpcStatus instantiates a new RpcStatus object This constructor will assign default values to properties that have it defined, and makes sure properties required by API are set, but the set of arguments will change when the set of required properties is changed

func NewRpcStatusWithDefaults

func NewRpcStatusWithDefaults() *RpcStatus

NewRpcStatusWithDefaults instantiates a new RpcStatus object This constructor will only assign default values to properties that have it defined, but it doesn't guarantee that properties required by API are set

func (*RpcStatus) GetCode

func (o *RpcStatus) GetCode() int32

GetCode returns the Code field value if set, zero value otherwise.

func (*RpcStatus) GetCodeOk

func (o *RpcStatus) GetCodeOk() (*int32, bool)

GetCodeOk returns a tuple with the Code field value if set, nil otherwise and a boolean to check if the value has been set.

func (*RpcStatus) GetDetails

func (o *RpcStatus) GetDetails() []ProtobufAny

GetDetails returns the Details field value if set, zero value otherwise.

func (*RpcStatus) GetDetailsOk

func (o *RpcStatus) GetDetailsOk() ([]ProtobufAny, bool)

GetDetailsOk returns a tuple with the Details field value if set, nil otherwise and a boolean to check if the value has been set.

func (*RpcStatus) GetMessage

func (o *RpcStatus) GetMessage() string

GetMessage returns the Message field value if set, zero value otherwise.

func (*RpcStatus) GetMessageOk

func (o *RpcStatus) GetMessageOk() (*string, bool)

GetMessageOk returns a tuple with the Message field value if set, nil otherwise and a boolean to check if the value has been set.

func (*RpcStatus) HasCode

func (o *RpcStatus) HasCode() bool

HasCode returns a boolean if a field has been set.

func (*RpcStatus) HasDetails

func (o *RpcStatus) HasDetails() bool

HasDetails returns a boolean if a field has been set.

func (*RpcStatus) HasMessage

func (o *RpcStatus) HasMessage() bool

HasMessage returns a boolean if a field has been set.

func (RpcStatus) MarshalJSON

func (o RpcStatus) MarshalJSON() ([]byte, error)

func (*RpcStatus) SetCode

func (o *RpcStatus) SetCode(v int32)

SetCode gets a reference to the given int32 and assigns it to the Code field.

func (*RpcStatus) SetDetails

func (o *RpcStatus) SetDetails(v []ProtobufAny)

SetDetails gets a reference to the given []ProtobufAny and assigns it to the Details field.

func (*RpcStatus) SetMessage

func (o *RpcStatus) SetMessage(v string)

SetMessage gets a reference to the given string and assigns it to the Message field.

func (RpcStatus) ToMap

func (o RpcStatus) ToMap() (map[string]interface{}, error)

type ServerConfiguration

type ServerConfiguration struct {
	URL         string
	Description string
	Variables   map[string]ServerVariable
}

ServerConfiguration stores the information about a server

type ServerConfigurations

type ServerConfigurations []ServerConfiguration

ServerConfigurations stores multiple ServerConfiguration items

func (ServerConfigurations) URL

func (sc ServerConfigurations) URL(index int, variables map[string]string) (string, error)

URL formats template on a index using given variables

type ServerVariable

type ServerVariable struct {
	Description  string
	DefaultValue string
	EnumValues   []string
}

ServerVariable stores the information about a server variable

Jump to